@@ -7,7 +7,9 @@
 #' @return Boolean value.
 #' @examples
 #' # See if the documentation should be run.
-#' run_documentation()
-run_documentation = function() {
-  return(identical(Sys.getenv("IN_PKGDOWN"), "true"))
+#' run_docs_raybevel()
+run_docs_raybevel = function() {
+  return(identical(Sys.getenv("IN_PKGDOWN"), "true") && 
+         length(find.package("ggplot2",quiet = TRUE)) > 0 &&
+         length(find.package("spData",quiet = TRUE)) > 0)
 }
